@@ -7,7 +7,7 @@
 
 from __future__ import annotations
 
-__version__ = "8.6.0"
+from ._version import __version__
 
 try:
     from . import _core
@@ -26,6 +26,7 @@ from ._core import (
     ForeignObjectError,
     Job,
     JobUsageError,
+    Matrix,
     NameTree,
     NumberTree,
     ObjectHelper,
@@ -99,6 +100,7 @@ __all__ = [
     'ForeignObjectError',
     'Job',
     'JobUsageError',
+    'Matrix',
     'NameTree',
     'NumberTree',
     'ObjectHelper',
